BaseUserManager<T extends UserBaseModel> class abstract

Mixed-in types

Constructors

BaseUserManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
initCompleter ↔ Completer
getter/setter pair
isLogin → Future<bool>
no setter
oldLoginUserModel → T?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userLogDescription → Future<String>
根据登录状态,提供给监控系统(日志系统、Bugly、火山等) 的用户描述(含用户名、id、手机号)
no setter
userModel ↔ T?
BaseUserManager 的实现类会调用此方法
getter/setter pair

Methods

fireCacheGetCompleteEvent(UserCacheGetCompleteEvent event) → dynamic
发送通知--1、用户缓存数据获取完成
fireUserLoginStateChangeEvent(UserLoginStateChangeEvent event) → dynamic
发送通知--2、用户登录状态变更
fromUserCacheJson(Map<String, dynamic> cacheJson) → T
缓存数据的编解码
inherited
getCacheUserAuthToken() → Future<String?>
getCurrentAndOldCacheUser() → Future<void>
getUserLogDescription(bool isLogin) → String
logout() → void
退出登录
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestGetCacheUser(String cacheUserKey) → Future<T?>
requestRemoveCacheUser(String cacheUserKey) → Future<bool>
requestSaveCacheUser(String cacheUserKey, T? value) → Future<bool>
toCacheJson(T model) → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited