UserLoginStateChangeEvent class

用户登录状态变化的通知事件(状态变化的时候,必然伴随用户 token 的变更,请务必更新网络库的 token 值)

Constructors

UserLoginStateChangeEvent({required UserLoginState? loginState, bool? fromOverdue})

Properties

fromOverdue ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loginState ↔ UserLoginState?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited