UserLevelProtocal class

Constructors

UserLevelProtocal({int? level, String? levelName, String? levelImageUrl})

Properties

hashCode → int
The hash code for this object.
no setterinherited
level ↔ int?
getter/setter pair
levelImageUrl ↔ String?
getter/setter pair
levelName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited