UserBaseModel class

Constructors

UserBaseModel({required String userId, required String nickname, String? avatar, int? sex, String? authToken, String? tel})

Properties

authToken ↔ String?
getter/setter pair
avatar ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasLogin → bool
no setter
isTokenOvdue → bool
是否是token过期(常见于:异地登录/多设备登录)
no setter
loginState → UserLoginState
no setter
nickname ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sex ↔ int?
getter/setter pair
tel ↔ String?
getter/setter pair
userId ↔ String
getter/setter pair
userLogId → String
提供给监控系统(日志系统、Bugly、火山等) 的用户描述(含用户名、id、手机号)
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited